Returns the N parameter sets which resulted in the maximum scores from FUN.
Value
A list containing the FUN inputs which resulted in the highest returned Score.
If N > 1, a data.table is returned. Each row is a result from FUN, with results ordered by
descending Score.
Examples
scoringFunction <- function(x) {
a <- exp(-(2-x)^2)*1.5
b <- exp(-(4-x)^2)*2
c <- exp(-(6-x)^2)*1
return(list(Score = a+b+c))
}
bounds <- list(x = c(0,8))
Results <- bayesOpt(
FUN = scoringFunction
, bounds = bounds
, initPoints = 3
, iters.n = 2
, gsPoints = 10
)
#>
#> Running initial scoring function 3 times in 1 thread(s)...
print(getBestPars(Results))
#> $x
#> [1] 3.588488
#>