Returns 2 stacked plots - the top shows the results from FUN at each iteration. The bottom shows the utility from each point before the search took place.
Usage
# S3 method for class 'bayesOpt'
plot(x, ...)Examples
scoringFunction <- function(x) {
a <- exp(-(2-x)^2)*1.5
b <- exp(-(4-x)^2)*2
c <- exp(-(6-x)^2)*1
return(list(Score = a+b+c))
}
bounds <- list(x = c(0,8))
Results <- bayesOpt(
FUN = scoringFunction
, bounds = bounds
, initPoints = 3
, iters.n = 2
, gsPoints = 10
)
#>
#> Running initial scoring function 3 times in 1 thread(s)...
# This plot will also show in real time with parameter plotProgress = TRUE in bayesOpt()
plot(Results)
#> Warning: `aes_string()` was deprecated in ggplot2 3.0.0.
#> ℹ Please use tidy evaluation idioms with `aes()`.
#> ℹ See also `vignette("ggplot2-in-packages")` for more information.
#> ℹ The deprecated feature was likely used in the ParBayesianOptimization
#> package.
#> Please report the issue at
#> <https://github.com/novica/ParBayesianOptimization/issues>.